Description Usage Arguments Format Value Constructor Fields See Also
Represents a counterfactual likelihood where one or more likelihood factors has been replaced with an intervention as specified by intervention_list.
Inherits from Likelihood. Other factors (including their updates) are taken from an underlying observed_likelihood estimated from observed data.
1 2 3 |
... |
Passes all arguments to the constructor. See documentation for the Constructor below. |
R6Class object.
Likelihood object
make_CF_Likelihood(observed_likelihood, intervention_list, ...)
observed_likelihoodLikelihood obect specifying the relevant factors of the observed likelihood
intervention_listA list of objects inheriting from LF_base, representing the intervention.
...Not currently used.
observed_likelihoodLikelihood obect specifying the relevant factors of the observed likelihood
intervention_listA list of objects inheriting from LF_base, representing the intervention.
Other Likelihood objects: LF_base,
LF_derived, LF_emp,
LF_fit, LF_known,
LF_static, Likelihood,
Targeted_Likelihood,
define_lf
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.