Description Usage Format Value Current Issues Constructor Fields See Also
Parameter definition for the Treatment Specific Mean (TSM): $E_W[E_Y|A(Y|A=a|W)|$. Currently supports multiple static intervention nodes. Does yet not support dynamic rule or stochastic interventions.
1 |
R6Class object.
Param_base object
clever covariates doesn't support updates; always uses initial (necessary for iterative TMLE, e.g. stochastic intervention)
doesn't integrate over possible counterfactuals (necessary for stochastic intervention)
clever covariate gets recalculated all the time (inefficient)
define_param(Param_TSM, observed_likelihood, intervention_list, ..., outcome_node)
observed_likelihoodA Likelihood corresponding to the observed likelihood
intervention_listA list of objects inheriting from LF_base, representing the intervention.
...Not currently used.
outcome_nodecharacter, the name of the node that should be treated as the outcome
cf_likelihoodthe counterfactual likelihood for this treatment
intervention_listA list of objects inheriting from LF_base, representing the intervention
Other Parameters: Param_ATE,
Param_ATT, Param_base,
Param_delta, Param_mean,
define_param, tmle3_Fit
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.