Description Usage Format Value Constructor Methods Fields See Also
A parameter is a function of the likelihood. Once given a Likelihood object, a parameter will a value.
These objects also contain information about the efficient influence function (EIF) of a parameter, as well as its clever covariate(s).
1 |
R6Class object.
Param_base object
define_param(Param_base, observed_likelihood, ..., outcome_node)
observed_likelihoodA Likelihood corresponding to the observed likelihood
...Not currently used.
outcome_nodecharacter, the name of the node that should be treated as the outcome
clever_covariates(tmle_task = NULL)Get the clever covariates for an TMLE update step.
tmle_task: tmle3_Task to get clever covariate values for.
If NULL, the tmle_task used to train the observed likelihood will be used
estimates(tmle_task = NULL)Get the parameter estimates and influence curve values.
tmle_task: tmle3_Task to get clever covariate values for.
If NULL, the tmle_task used to train the observed likelihood will be used
observed_likelihoodthe observed likelihood
outcome_nodecharacter, the name of the outcome node
Other Parameters: Param_ATE,
Param_ATT, Param_TSM,
Param_delta, Param_mean,
define_param, tmle3_Fit
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.