tmle3_vim: Compute Variable Importance Measures (VIM) with any given...

Description Usage Arguments

Description

Compute Variable Importance Measures (VIM) with any given parameter

Usage

1
2
tmle3_vim(tmle_spec, data, node_list, learner_list = NULL,
  adjust_for_other_A = TRUE)

Arguments

tmle_spec

tmle3_Spec, defines the TMLE

data

data.frame, the raw data

node_list

list, defines which variables are which nodes

learner_list

list, defines which learners are used to fit which likelihood factors

adjust_for_other_A

Whether or not to adjust for other specified intervention nodes.


lurui0421/TMLE-for-causal-inference- documentation built on July 4, 2019, 1:03 p.m.